@@ -26,12 +26,21 @@ AUTHFAILURE = 'AuthFailure'
 # 地址没有弹性网卡信息。
 FAILEDOPERATION_ADDRESSENIINFONOTFOUND = 'FailedOperation.AddressEniInfoNotFound'
 
+# 账户余额不足。
+FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
+
 # 不支持的地域。
 FAILEDOPERATION_INVALIDREGION = 'FailedOperation.InvalidRegion'
 
+# 未找到实例的主网卡。
+FAILEDOPERATION_MASTERENINOTFOUND = 'FailedOperation.MasterEniNotFound'
+
 # 网络探测超时，请稍后重试。
 FAILEDOPERATION_NETDETECTTIMEOUT = 'FailedOperation.NetDetectTimeOut'
 
+# 任务执行失败。
+FAILEDOPERATION_TASKFAILED = 'FailedOperation.TaskFailed'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -293,6 +302,9 @@ INVALIDPARAMETERVALUE_RESOURCENOTSUPPORT = 'InvalidParameterValue.ResourceNotSup
 # 子网CIDR冲突。
 INVALIDPARAMETERVALUE_SUBNETCONFLICT = 'InvalidParameterValue.SubnetConflict'
 
+# CIDR与同一个私有网络内的另一个子网发生重叠。
+INVALIDPARAMETERVALUE_SUBNETOVERLAP = 'InvalidParameterValue.SubnetOverlap'
+
 # 子网与辅助Cidr网段重叠。
 INVALIDPARAMETERVALUE_SUBNETOVERLAPASSISTCIDR = 'InvalidParameterValue.SubnetOverlapAssistCidr'
 
@@ -461,6 +473,12 @@ LIMITEXCEEDED_TAGTAGSEXCEEDED = 'LimitExceeded.TagTagsExceeded'
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 指定公网IP处于隔离状态。
+OPERATIONDENIED_ADDRESSINARREARS = 'OperationDenied.AddressInArrears'
+
+# 互斥的任务正在执行。
+OPERATIONDENIED_MUTEXTASKRUNNING = 'OperationDenied.MutexTaskRunning'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -488,6 +506,9 @@ RESOURCEUNAVAILABLE_SERVICEWHITELISTNOTADDED = 'ResourceUnavailable.ServiceWhite
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 无权限申请AnycastEip资源。
+UNAUTHORIZEDOPERATION_ANYCASTEIP = 'UnauthorizedOperation.AnycastEip'
+
 # 绑定关系不存在。
 UNAUTHORIZEDOPERATION_ATTACHMENTNOTFOUND = 'UnauthorizedOperation.AttachmentNotFound'
 
@@ -620,6 +641,9 @@ UNSUPPORTEDOPERATION_INCORRECTADDRESSRESOURCETYPE = 'UnsupportedOperation.Incorr
 # 用户配置的实例和路由表不匹配。
 UNSUPPORTEDOPERATION_INSTANCEANDRTBNOTMATCH = 'UnsupportedOperation.InstanceAndRtbNotMatch'
 
+# 指定实例资源不匹配。
+UNSUPPORTEDOPERATION_INSTANCEMISMATCH = 'UnsupportedOperation.InstanceMismatch'
+
 # 跨账号场景下不支持普通账号实例关联自驾云账号云联网。
 UNSUPPORTEDOPERATION_INSTANCEORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.InstanceOrdinaryAccountRefuseAttach'
 
@@ -662,6 +686,9 @@ UNSUPPORTEDOPERATION_ISPNOTSUPPORTED = 'UnsupportedOperation.IspNotSupported'
 # 指定的CDC已存在本地网关。
 UNSUPPORTEDOPERATION_LOCALGATEWAYALREADYEXISTS = 'UnsupportedOperation.LocalGatewayAlreadyExists'
 
+# 账户不支持修改公网IP的该属性。
+UNSUPPORTEDOPERATION_MODIFYADDRESSATTRIBUTE = 'UnsupportedOperation.ModifyAddressAttribute'
+
 # 资源互斥操作任务正在执行。
 UNSUPPORTEDOPERATION_MUTEXOPERATIONTASKRUNNING = 'UnsupportedOperation.MutexOperationTaskRunning'
 
@@ -695,6 +722,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTEDUPDATECCNROUTEPUBLISH = 'UnsupportedOperation.N
 # 指定的路由策略不支持发布或撤销至云联网。
 UNSUPPORTEDOPERATION_NOTIFYCCN = 'UnsupportedOperation.NotifyCcn'
 
+# 此产品计费方式已下线，请尝试其他计费方式。
+UNSUPPORTEDOPERATION_OFFLINECHARGETYPE = 'UnsupportedOperation.OfflineChargeType'
+
 # 仅支持专业版Ckafka。
 UNSUPPORTEDOPERATION_ONLYSUPPORTPROFESSIONKAFKA = 'UnsupportedOperation.OnlySupportProfessionKafka'
 
@@ -719,12 +749,24 @@ UNSUPPORTEDOPERATION_PUBLICIPADDRESSNOTBILLEDBYTRAFFIC = 'UnsupportedOperation.P
 # 当前账号不能在该地域使用产品。
 UNSUPPORTEDOPERATION_PURCHASELIMIT = 'UnsupportedOperation.PurchaseLimit'
 
+# 记录已存在。
+UNSUPPORTEDOPERATION_RECORDEXISTS = 'UnsupportedOperation.RecordExists'
+
+# 记录不存在。
+UNSUPPORTEDOPERATION_RECORDNOTEXISTS = 'UnsupportedOperation.RecordNotExists'
+
 # 输入的资源ID与IP绑定的资源不匹配，请检查。
 UNSUPPORTEDOPERATION_RESOURCEMISMATCH = 'UnsupportedOperation.ResourceMismatch'
 
+# 未找到相关角色，请确认角色是否授权。
+UNSUPPORTEDOPERATION_ROLENOTFOUND = 'UnsupportedOperation.RoleNotFound'
+
 # 指定的终端节点服务所创建的终端节点不支持绑定安全组。
 UNSUPPORTEDOPERATION_SPECIALENDPOINTSERVICE = 'UnsupportedOperation.SpecialEndPointService'
 
+# SslVpnClientId 不存在。
+UNSUPPORTEDOPERATION_SSLVPNCLIENTIDNOTFOUND = 'UnsupportedOperation.SslVpnClientIdNotFound'
+
 # 中继网卡不支持该操作。
 UNSUPPORTEDOPERATION_SUBENINOTSUPPORTTRUNKING = 'UnsupportedOperation.SubEniNotSupportTrunking'
 
@@ -761,6 +803,9 @@ UNSUPPORTEDOPERATION_UNBINDEIP = 'UnsupportedOperation.UnbindEIP'
 # 账户还有未支付订单，请先完成付款。
 UNSUPPORTEDOPERATION_UNPAIDORDERALREADYEXISTS = 'UnsupportedOperation.UnpaidOrderAlreadyExists'
 
+# 不支持绑定LocalZone弹性公网IP。
+UNSUPPORTEDOPERATION_UNSUPPORTEDBINDLOCALZONEEIP = 'UnsupportedOperation.UnsupportedBindLocalZoneEIP'
+
 # 指定机型不支持弹性网卡。
 UNSUPPORTEDOPERATION_UNSUPPORTEDINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedInstanceFamily'
 
